@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.48';
+our $VERSION = '0.52';
 
 use Exporter;
 our @ISA            = qw( bigint );
@@ -230,22 +230,22 @@ bignum - Transparent BigNumber support for Perl
 
 =head1 SYNOPSIS
 
-  use bignum;
+    use bignum;
 
-  $x = 2 + 4.5,"\n";                    # BigFloat 6.5
-  print 2 ** 512 * 0.1,"\n";            # really is what you think it is
-  print inf * inf,"\n";                 # prints inf
-  print NaN * 3,"\n";                   # prints NaN
+    $x = 2 + 4.5,"\n";              # BigFloat 6.5
+    print 2 ** 512 * 0.1,"\n";      # really is what you think it is
+    print inf * inf,"\n";           # prints inf
+    print NaN * 3,"\n";             # prints NaN
 
-  {
-    no bignum;
-    print 2 ** 256,"\n";                # a normal Perl scalar now
-  }
+    {
+        no bignum;
+        print 2 ** 256,"\n";        # a normal Perl scalar now
+    }
 
-  # for older Perls, import into current package:
-  use bignum qw/hex oct/;
-  print hex("0x1234567890123490"),"\n";
-  print oct("01234567890123490"),"\n";
+    # for older Perls, import into current package:
+    use bignum qw/hex oct/;
+    print hex("0x1234567890123490"),"\n";
+    print oct("01234567890123490"),"\n";
 
 =head1 DESCRIPTION
 
@@ -255,7 +255,7 @@ respectively.
 
 If you do
 
-        use bignum;
+    use bignum;
 
 at the top of your script, Math::BigFloat and Math::BigInt will be loaded
 and any constant number will be converted to an object (Math::BigFloat for
@@ -263,20 +263,20 @@ floats like 3.1415 and Math::BigInt for integers like 1234).
 
 So, the following line:
 
-        $x = 1234;
+    $x = 1234;
 
 creates actually a Math::BigInt and stores a reference to in $x.
 This happens transparently and behind your back, so to speak.
 
 You can see this with the following:
 
-        perl -Mbignum -le 'print ref(1234)'
+    perl -Mbignum -le 'print ref(1234)'
 
 Don't worry if it says Math::BigInt::Lite, bignum and friends will use Lite
 if it is installed since it is faster for some operations. It will be
 automatically upgraded to BigInt whenever necessary:
 
-        perl -Mbignum -le 'print ref(2**255)'
+    perl -Mbignum -le 'print ref(2**255)'
 
 This also means it is a bad idea to check for some specific package, since
 the actual contents of $x might be something unexpected. Due to the
@@ -285,29 +285,29 @@ transparent way of bignum C<ref()> should not be necessary, anyway.
 Since Math::BigInt and BigFloat also overload the normal math operations,
 the following line will still work:
 
-        perl -Mbignum -le 'print ref(1234+1234)'
+    perl -Mbignum -le 'print ref(1234+1234)'
 
 Since numbers are actually objects, you can call all the usual methods from
 BigInt/BigFloat on them. This even works to some extent on expressions:
 
-        perl -Mbignum -le '$x = 1234; print $x->bdec()'
-        perl -Mbignum -le 'print 1234->copy()->binc();'
-        perl -Mbignum -le 'print 1234->copy()->binc->badd(6);'
-        perl -Mbignum -le 'print +(1234)->copy()->binc()'
+    perl -Mbignum -le '$x = 1234; print $x->bdec()'
+    perl -Mbignum -le 'print 1234->copy()->binc();'
+    perl -Mbignum -le 'print 1234->copy()->binc->badd(6);'
+    perl -Mbignum -le 'print +(1234)->copy()->binc()'
 
 (Note that print doesn't do what you expect if the expression starts with
 '(' hence the C<+>)
 
 You can even chain the operations together as usual:
 
-        perl -Mbignum -le 'print 1234->copy()->binc->badd(6);'
-        1241
+    perl -Mbignum -le 'print 1234->copy()->binc->badd(6);'
+    1241
 
 Under bignum (or bigint or bigrat), Perl will "upgrade" the numbers
 appropriately. This means that:
 
-        perl -Mbignum -le 'print 1234+4.5'
-        1238.5
+    perl -Mbignum -le 'print 1234+4.5'
+    1238.5
 
 will work correctly. These mixed cases don't do always work when using
 Math::BigInt or Math::BigFloat alone, or at least not in the way normal Perl
@@ -316,19 +316,19 @@ scalars work.
 If you do want to work with large integers like under C<use integer;>, try
 C<use bigint;>:
 
-        perl -Mbigint -le 'print 1234.5+4.5'
-        1238
+    perl -Mbigint -le 'print 1234.5+4.5'
+    1238
 
 There is also C<use bigrat;> which gives you big rationals:
 
-        perl -Mbigrat -le 'print 1234+4.1'
-        12381/10
+    perl -Mbigrat -le 'print 1234+4.1'
+    12381/10
 
 The entire upgrading/downgrading is still experimental and might not work
 as you expect or may even have bugs. You might get errors like this:
 
-        Can't use an undefined value as an ARRAY reference at
-        /usr/local/lib/perl5/5.8.0/Math/BigInt/Calc.pm line 864
+    Can't use an undefined value as an ARRAY reference at
+    /usr/local/lib/perl5/5.8.0/Math/BigInt/Calc.pm line 864
 
 This means somewhere a routine got a BigFloat/Lite but expected a BigInt (or
 vice versa) and the upgrade/downgrad path was missing. This is a bug, please
@@ -359,7 +359,7 @@ The following options exist:
 This sets the accuracy for all math operations. The argument must be greater
 than or equal to zero. See Math::BigInt's bround() function for details.
 
-        perl -Mbignum=a,50 -le 'print sqrt(20)'
+    perl -Mbignum=a,50 -le 'print sqrt(20)'
 
 Note that setting precision and accuracy at the same time is not possible.
 
@@ -370,7 +370,7 @@ integer. Negative values mean a fixed number of digits after the dot, while
 a positive value rounds to this digit left from the dot. 0 or 1 mean round to
 integer. See Math::BigInt's bfround() function for details.
 
-        perl -Mbignum=p,-50 -le 'print sqrt(20)'
+    perl -Mbignum=p,-50 -le 'print sqrt(20)'
 
 Note that setting precision and accuracy at the same time is not possible.
 
@@ -383,12 +383,12 @@ Math::BigInt/Math::BigFloat.
 
 Load a different math lib, see L<Math Library>.
 
-        perl -Mbignum=l,GMP -e 'print 2 ** 512'
+    perl -Mbignum=l,GMP -e 'print 2 ** 512'
 
 Currently there is no way to specify more than one library on the command
 line. This means the following does not work:
 
-        perl -Mbignum=l,GMP,Pari -e 'print 2 ** 512'
+    perl -Mbignum=l,GMP,Pari -e 'print 2 ** 512'
 
 This will be hopefully fixed soon ;)
 
@@ -410,7 +410,7 @@ overridden in the current scope whenever the bigint pragma is active.
 
 This prints out the name and version of all modules used and then exits.
 
-        perl -Mbignum=v
+    perl -Mbignum=v
 
 =back
 
@@ -428,35 +428,35 @@ might morph into a different class than BigFloat.
 But a warning is in order. When using the following to make a copy of a number,
 only a shallow copy will be made.
 
-        $x = 9; $y = $x;
-        $x = $y = 7;
+    $x = 9; $y = $x;
+    $x = $y = 7;
 
 If you want to make a real copy, use the following:
 
-        $y = $x->copy();
+    $y = $x->copy();
 
 Using the copy or the original with overloaded math is okay, e.g. the
 following work:
 
-        $x = 9; $y = $x;
-        print $x + 1, " ", $y,"\n";     # prints 10 9
+    $x = 9; $y = $x;
+    print $x + 1, " ", $y,"\n";     # prints 10 9
 
 but calling any method that modifies the number directly will result in
 B<both> the original and the copy being destroyed:
 
-        $x = 9; $y = $x;
-        print $x->badd(1), " ", $y,"\n";        # prints 10 10
+    $x = 9; $y = $x;
+    print $x->badd(1), " ", $y,"\n";        # prints 10 10
 
-        $x = 9; $y = $x;
-        print $x->binc(1), " ", $y,"\n";        # prints 10 10
+    $x = 9; $y = $x;
+    print $x->binc(1), " ", $y,"\n";        # prints 10 10
 
-        $x = 9; $y = $x;
-        print $x->bmul(2), " ", $y,"\n";        # prints 18 18
+    $x = 9; $y = $x;
+    print $x->bmul(2), " ", $y,"\n";        # prints 18 18
 
 Using methods that do not modify, but test the contents works:
 
-        $x = 9; $y = $x;
-        $z = 9 if $x->is_zero();                # works fine
+    $x = 9; $y = $x;
+    $z = 9 if $x->is_zero();                # works fine
 
 See the documentation about the copy constructor and C<=> in overload, as
 well as the documentation in BigInt for further details.
@@ -475,36 +475,36 @@ handle bareword C<NaN> properly.
 
 =item e
 
-        # perl -Mbignum=e -wle 'print e'
+    # perl -Mbignum=e -wle 'print e'
 
 Returns Euler's number C<e>, aka exp(1).
 
 =item PI()
 
-        # perl -Mbignum=PI -wle 'print PI'
+    # perl -Mbignum=PI -wle 'print PI'
 
 Returns PI.
 
 =item bexp()
 
-        bexp($power,$accuracy);
+    bexp($power,$accuracy);
 
 Returns Euler's number C<e> raised to the appropriate power, to
 the wanted accuracy.
 
 Example:
 
-        # perl -Mbignum=bexp -wle 'print bexp(1,80)'
+    # perl -Mbignum=bexp -wle 'print bexp(1,80)'
 
 =item bpi()
 
-        bpi($accuracy);
+    bpi($accuracy);
 
 Returns PI to the wanted accuracy.
 
 Example:
 
-        # perl -Mbignum=bpi -wle 'print bpi(80)'
+    # perl -Mbignum=bpi -wle 'print bpi(80)'
 
 =item upgrade()
 
@@ -513,13 +513,13 @@ C<$Math::BigInt::upgrade>.
 
 =item in_effect()
 
-        use bignum;
+    use bignum;
 
-        print "in effect\n" if bignum::in_effect;       # true
-        {
-          no bignum;
-          print "in effect\n" if bignum::in_effect;     # false
-        }
+    print "in effect\n" if bignum::in_effect;       # true
+    {
+        no bignum;
+        print "in effect\n" if bignum::in_effect;   # false
+    }
 
 Returns true or false if C<bignum> is in effect in the current scope.
 
@@ -532,16 +532,16 @@ This method only works on Perl v5.9.4 or later.
 Math with the numbers is done (by default) by a module called
 Math::BigInt::Calc. This is equivalent to saying:
 
-        use bignum lib => 'Calc';
+    use bignum lib => 'Calc';
 
 You can change this by using:
 
-        use bignum lib => 'GMP';
+    use bignum lib => 'GMP';
 
 The following would first try to find Math::BigInt::Foo, then
 Math::BigInt::Bar, and when this also fails, revert to Math::BigInt::Calc:
 
-        use bignum lib => 'Foo,Math::BigInt::Bar';
+    use bignum lib => 'Foo,Math::BigInt::Bar';
 
 Please see respective module documentation for further details.
 
@@ -549,11 +549,11 @@ Using C<lib> warns if none of the specified libraries can be found and
 L<Math::BigInt> did fall back to one of the default libraries.
 To suppress this warning, use C<try> instead:
 
-        use bignum try => 'GMP';
+    use bignum try => 'GMP';
 
 If you want the code to die instead of falling back, use C<only> instead:
 
-        use bignum only => 'GMP';
+    use bignum only => 'GMP';
 
 =head2 INTERNAL FORMAT
 
@@ -616,22 +616,22 @@ will not happen unless you specifically ask for it with the two
 import tags "hex" and "oct" - and then it will be global and cannot be
 disabled inside a scope with "no bigint":
 
-        use bigint qw/hex oct/;
+    use bigint qw/hex oct/;
 
+    print hex("0x1234567890123456");
+    {
+        no bigint;
         print hex("0x1234567890123456");
-        {
-                no bigint;
-                print hex("0x1234567890123456");
-        }
+    }
 
 The second call to hex() will warn about a non-portable constant.
 
 Compare this to:
 
-        use bigint;
+    use bigint;
 
-        # will warn only under older than v5.9.4
-        print hex("0x1234567890123456");
+    # will warn only under older than v5.9.4
+    print hex("0x1234567890123456");
 
 =back
 
@@ -643,24 +643,24 @@ the others to do the work.
 
 The following modules are currently used by bignum:
 
-        Math::BigInt::Lite      (for speed, and only if it is loadable)
-        Math::BigInt
-        Math::BigFloat
+    Math::BigInt::Lite      (for speed, and only if it is loadable)
+    Math::BigInt
+    Math::BigFloat
 
 =head1 EXAMPLES
 
 Some cool command line examples to impress the Python crowd ;)
 
-        perl -Mbignum -le 'print sqrt(33)'
-        perl -Mbignum -le 'print 2*255'
-        perl -Mbignum -le 'print 4.5+2*255'
-        perl -Mbignum -le 'print 3/7 + 5/7 + 8/3'
-        perl -Mbignum -le 'print 123->is_odd()'
-        perl -Mbignum -le 'print log(2)'
-        perl -Mbignum -le 'print exp(1)'
-        perl -Mbignum -le 'print 2 ** 0.5'
-        perl -Mbignum=a,65 -le 'print 2 ** 0.2'
-        perl -Mbignum=a,65,l,GMP -le 'print 7 ** 7777'
+    perl -Mbignum -le 'print sqrt(33)'
+    perl -Mbignum -le 'print 2*255'
+    perl -Mbignum -le 'print 4.5+2*255'
+    perl -Mbignum -le 'print 3/7 + 5/7 + 8/3'
+    perl -Mbignum -le 'print 123->is_odd()'
+    perl -Mbignum -le 'print log(2)'
+    perl -Mbignum -le 'print exp(1)'
+    perl -Mbignum -le 'print 2 ** 0.5'
+    perl -Mbignum=a,65 -le 'print 2 ** 0.2'
+    perl -Mbignum=a,65,l,GMP -le 'print 7 ** 7777'
 
 =head1 BUGS
 
@@ -680,26 +680,26 @@ You can also look for information at:
 
 =over 4
 
+=item * GitHub
+
+L<https://github.com/pjacklam/p5-bignum>
+
 =item * RT: CPAN's request tracker
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=bignum>
+L<https://rt.cpan.org/Dist/Display.html?Name=bignum>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item * MetaCPAN
 
-L<http://annocpan.org/dist/bignum>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/dist/bignum>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/bignum/>
+L<https://metacpan.org/release/bignum>
 
 =item * CPAN Testers Matrix
 
 L<http://matrix.cpantesters.org/?dist=bignum>
 
+=item * CPAN Ratings
+
+L<https://cpanratings.perl.org/dist/bignum>
+
 =back
 
 =head1 LICENSE
@@ -724,7 +724,7 @@ L<Math::BigInt::FastCalc>, L<Math::BigInt::Pari> and L<Math::BigInt::GMP>.
 
 =item *
 
-Maintained by Peter John Acklam E<lt>pjacklam@gmail.com<gt>, 2014-.
+Maintained by Peter John Acklam E<lt>pjacklam@gmail.comE<gt>, 2014-.
 
 =back
 
